import { Component, OnInit, EventEmitter } from '@angular/core';
import { ProductoService } from 'src/app/services/producto.service';
import { Producto } from 'src/app/wrappers/producto';
import { Categoria } from 'src/app/wrappers/categoria';
import { APP_SETTINGS } from 'src/etc/AppSettings';
import { Router } from '@angular/router';

@Component({
  selector: 'app-busqueda-productos',
  templateUrl: './busqueda-productos.component.html',
  styleUrls: ['./busqueda-productos.component.scss']
})
export class BusquedaProductosComponent implements OnInit {

  private productos: Producto[] = [];
  private auxProductos: Producto[] = [];
  private searchTerm: string = '';
  private categoriaActive: number = null;
  private showSpinner: boolean = true;
  private queMostrar: string = 'todos';
  private apiDeboSuite: string = APP_SETTINGS.apiDeboSuite;
  private categorias: Categoria[] = [];
  private blurFocus = new EventEmitter();
  private ordenandoByVendidos = true;
  private title: string = 'Búsqueda'

  constructor(
    private productoService: ProductoService,
    private router: Router) { }

  ngOnInit() {

    this.queMostrar = this.productoService.mostrar;

    this.productoService.getCategorias()
      .subscribe((categorias: Categoria[]) => {

        switch (this.queMostrar) {
          case 'todos':
            this.categorias = categorias;
            this.categoriaActive = 0;
            this.title = 'Búsqueda';
            break;
          case 'promociones':
            this.categorias = categorias;
            this.categoriaActive = 1;
            this.title = 'Promociones';
            break;
          case 'ordenar':
            this.categorias = categorias.filter((categoria: Categoria) => {
              return categoria.ES_PEDIDO;
            });
            this.categoriaActive = 0;
            this.title = 'Ordenar';
            break;
          default:
            this.categorias = categorias;
            this.categoriaActive = 0;
            this.title = 'Búsqueda';
            break;
        }
      });

    this.productoService.productoAcargar = undefined;
    this.productoService.getAll()
      .subscribe((data: Producto[]) => {

        this.setProductosSinImagen(data);
        
        if (this.queMostrar == 'ordenar') {

          this.categorias.forEach((categoria: Categoria) => {

            let tempProductos = data.filter((producto: Producto) => {
              return producto.categoria_selfservice == categoria.id;
            });

            this.productos = this.productos.concat(tempProductos);

          });
        } else {
          this.productos = data;
        }
        this.filterItems();
      }, (error) => {
        this.showSpinner = false;
        console.error(error);
      });
  }

  filterItems() {

    this.auxProductos = this.productos.filter(x => {
      if (this.categoriaActive === 0) {
        return x.DET_LAR.toLowerCase().includes(this.searchTerm.toLowerCase());
      }
      else {
        return x.DET_LAR.toLowerCase().includes(this.searchTerm.toLowerCase()) &&
          x.categoria_selfservice === this.categoriaActive;
      }
    });

    this.ordenar();

  }

  agregarAlCarrito(producto: Producto) {

    producto.cantidad = 1;
    this.productoService.productos.push(producto);
  }

  ordenar() {

    if (this.ordenandoByVendidos) {

      this.auxProductos.sort((a, b) => {
        return b.cantidadVendida - a.cantidadVendida;
      });
    }

  }

  private elegirProducto(producto: Producto) {

    if (producto.PRO) {

      let imagenes = producto.imagenes;
      this.productoService.getPromocionByCodigos(producto.CodSec, producto.CodArt)
        .subscribe(res => {

          this.productoService.productoAcargar = res[0];
          this.productoService.productoAcargar.imagenes = imagenes;
          this.router.navigate(['inicio']);
        },
          error => { console.error(error); }
        );
    } else {

      this.productoService.productoAcargar = producto;
      this.router.navigate(['inicio']);
    }

  }

  private setProductosSinImagen(productos: Producto[]) {

    productos.forEach((producto: Producto) => {
      producto.imagenes = producto.imagenes.length == 0 ?
        [{ imagen: 'noImage.jpg' }] : producto.imagenes;
    })
  }
}
